@@ -83,6 +83,6 @@ final class Albums3Method
         Xml3_Data::set_offset($input['offset'] ?? 0);
         Xml3_Data::set_limit($input['limit'] ?? 0);
         ob_end_clean();
-        echo Xml3_Data::albums($results, $include, $user);
+        echo Xml3_Data::albums($results, $include, $user, $input['auth']);
     }
 }
