@@ -95,12 +95,12 @@ final class Albums4Method
             case 'json':
                 Json4_Data::set_offset($input['offset'] ?? 0);
                 Json4_Data::set_limit($input['limit'] ?? 0);
-                echo Json4_Data::albums($results, $include, $user);
+                echo Json4_Data::albums($results, $include, $user, $input['auth']);
                 break;
             default:
                 Xml4_Data::set_offset($input['offset'] ?? 0);
                 Xml4_Data::set_limit($input['limit'] ?? 0);
-                echo Xml4_Data::albums($results, $include, $user);
+                echo Xml4_Data::albums($results, $include, $user, $input['auth']);
         }
     }
 }
