@@ -122,13 +122,13 @@ final class LabelArtistsMethod
                 Json_Data::set_offset((int)($input['offset'] ?? 0));
                 Json_Data::set_limit($input['limit'] ?? 0);
                 Json_Data::set_count($browse->get_total());
-                echo Json_Data::artists($results, $include, $user);
+                echo Json_Data::artists($results, $include, $user, $input['auth']);
                 break;
             default:
                 Xml_Data::set_offset((int)($input['offset'] ?? 0));
                 Xml_Data::set_limit($input['limit'] ?? 0);
                 Xml_Data::set_count($browse->get_total());
-                echo Xml_Data::artists($results, $include, $user);
+                echo Xml_Data::artists($results, $include, $user, $input['auth']);
         }
 
         return true;
