@@ -1641,11 +1641,13 @@ class Subsonic_Xml_Data
      * addPodcasts
      * @param Podcast[] $podcasts
      */
-    public static function addPodcasts(SimpleXMLElement $xml, array $podcasts, bool $includeEpisodes = true): SimpleXMLElement
+    public static function addPodcasts(SimpleXMLElement $xml, array $podcasts, bool $includeEpisodes = true, ?string $sub_id = null): SimpleXMLElement
     {
         $xpodcasts = self::_addChildToResultXml($xml, 'podcasts');
         foreach ($podcasts as $podcast) {
-            $sub_id   = Subsonic_Api::getPodcastSubId($podcast->getId());
+            $sub_id = (!empty($sub_id))
+                ? $sub_id
+                : Subsonic_Api::getPodcastSubId($podcast->getId());
             $xchannel = self::_addChildToResultXml($xpodcasts, 'channel');
             $xchannel->addAttribute('id', $sub_id);
             $xchannel->addAttribute('url', $podcast->getFeedUrl());
