@@ -358,8 +358,8 @@ final class AlbumSearch implements SearchInterface
                     $parameters[] = $input;
                     break;
                 case 'genre_count_album':
-                    $where[]       = "`album`.`id` IN (SELECT `tag_map`.`object_id` FROM `tag_map` LEFT JOIN `tag` ON `tag_map`.`tag_id` = `tag`.`id` AND `tag`.`is_hidden` = 0 AND `tag`.`album` $operator_sql ? WHERE `tag_map`.`object_type`='album' AND `tag`.`id` IS NOT NULL)";
-                    $parameters[]  = $input;
+                    $where[]      = "`album`.`id` IN (SELECT `tag_map`.`object_id` FROM `tag_map` LEFT JOIN `tag` ON `tag_map`.`tag_id` = `tag`.`id` AND `tag`.`is_hidden` = 0 AND `tag`.`album` $operator_sql ? WHERE `tag_map`.`object_type`='album' AND `tag`.`id` IS NOT NULL)";
+                    $parameters[] = $input;
                     break;
                 case 'genre_count_artist':
                     $where[]           = "`artist`.`id` IN (SELECT `tag_map`.`object_id` FROM `tag_map` LEFT JOIN `tag` ON `tag_map`.`tag_id` = `tag`.`id` AND `tag`.`is_hidden` = 0 AND `tag`.`artist` $operator_sql ? WHERE `tag_map`.`object_type`='artist' AND `tag`.`id` IS NOT NULL)";
@@ -414,8 +414,9 @@ final class AlbumSearch implements SearchInterface
                     $join['song'] = true;
                     break;
                 case 'has_image':
-                    $where[]            = ($operator_sql == '1') ? "`has_image`.`object_id` IS NOT NULL" : "`has_image`.`object_id` IS NULL";
-                    $table['has_image'] = "LEFT JOIN (SELECT `object_id` FROM `image` WHERE `object_type` = 'album') AS `has_image` ON `album`.`id` = `has_image`.`object_id`";
+                    $where[] = ($operator_sql == '1')
+                        ? "`album`.`id` IN (SELECT `object_id` FROM `image` WHERE `object_type` = 'album' AND `size` = 'original')"
+                        : "`album`.`id` NOT IN (SELECT `object_id` FROM `image` WHERE `object_type` = 'album' AND `size` = 'original')";
                     break;
                 case 'image_height':
                 case 'image_width':
