@@ -85,9 +85,9 @@ class Podcast_Episode extends database_object implements
 
     public int $update_time;
 
-    public int $total_count;
+    public int $total_count = 0;
 
-    public int $total_skip;
+    public int $total_skip = 0;
 
     public int $catalog;
 
